@@ -23,20 +23,15 @@ __all__ = [
     ]
 
 
+from contextlib import contextmanager
 import json
 import os
 import stat
 import subprocess
 
 from contextlib import closing
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
 from unittest import skipUnless
 
-
 from debian.deb822 import Deb822
 # BAW 2013-04-16: Get the DebFile class from here because of compatibility
 # issues.  See the comments in that module for details.
@@ -45,9 +40,10 @@ from click.install import DebFile
 from click import osextras
 from click.install import ClickInstaller, ClickInstallerPermissionDenied
 from click.preinst import static_preinst
-from click.tests.helpers import TestCase, mkfile, touch
+from click.tests.helpers import TestCase, mkfile, mock, touch
 
 
+@contextmanager
 def mock_quiet_subprocess_call():
     original_call = subprocess.call
 
@@ -59,7 +55,9 @@ def mock_quiet_subprocess_call():
                 return original_call(
                     *args, stdout=devnull, stderr=devnull, **kwargs)
 
-    return mock.patch("subprocess.call", side_effect=side_effect)
+    with mock.patch("subprocess.call") as mock_call:
+        mock_call.side_effect = side_effect
+        yield mock_call
 
 
 class TestClickInstaller(TestCase):
@@ -303,7 +301,7 @@ class TestClickInstaller(TestCase):
         self.make_framework(installer, "ubuntu-sdk-13.10")
         with mock_quiet_subprocess_call():
             installer.install(path)
-        self.assertCountEqual([".click.log", "test-package"], os.listdir(root))
+        self.assertCountEqual([".click", "test-package"], os.listdir(root))
         package_dir = os.path.join(root, "test-package")
         self.assertCountEqual(["1.0", "current"], os.listdir(package_dir))
         inst_dir = os.path.join(package_dir, "current")
@@ -399,7 +397,7 @@ class TestClickInstaller(TestCase):
         self.make_framework(installer, "ubuntu-sdk-13.10")
         with mock_quiet_subprocess_call():
             installer.install(path)
-        self.assertCountEqual([".click.log", "test-package"], os.listdir(root))
+        self.assertCountEqual([".click", "test-package"], os.listdir(root))
         self.assertCountEqual(
             ["1.0", "1.1", "current"], os.listdir(package_dir))
         self.assertTrue(os.path.islink(inst_dir))
